@@ -25,8 +25,12 @@ const (
 	MasterCASecretName  = "master-certs"
 	CollectorSecretName = "fluentd"
 
-	/* #nosec - suppressing rule G101 */
-	KibanaSessionSecretName = "kibana-session-secret"
+	// Disable gosec linter, complains "possible hard-coded secret"
+	CollectorSecretsDir     = "/var/run/ocp-collector/secrets" //nolint:gosec
+	KibanaSessionSecretName = "kibana-session-secret"          //nolint:gosec
+
+	LegacySecureforward = "_LEGACY_SECUREFORWARD"
+	LegacySyslog        = "_LEGACY_SYSLOG"
 )
 
 var ReconcileForGlobalProxyList = []string{FluentdTrustedCAName}
