@@ -1014,20 +1014,21 @@ var _ = Describe("Generating fluentd config", func() {
 				<match **>
 					# https://docs.fluentd.org/v1.0/articles/in_forward
 				@type forward
+				heartbeat_type none
 
 				<buffer>
 					@type file
 					path '/var/lib/fluentd/secureforward_receiver'
 					queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-          chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
-          flush_mode interval
+					total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+					chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
+					flush_mode interval
 					flush_interval 5s
 					flush_at_shutdown true
 					flush_thread_count 2
-          retry_type exponential_backoff
-          retry_wait 1s
-          retry_max_interval 60s
+					retry_type exponential_backoff
+					retry_wait 1s
+					retry_max_interval 60s
 					retry_forever true
 					# the systemd journald 0.0.8 input plugin will just throw away records if the buffer
 					# queue limit is hit - 'block' will halt further reads and keep retrying to flush the
